==> haskell-monad-dijkstra-0.1.1.5-166-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-dijkstra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-dijkstra
version:              0.1.1.5
visibility:           public
id:                   monad-dijkstra-0.1.1.5-HpxdsNARl13HIeUuipBx7S
key:                  monad-dijkstra-0.1.1.5-HpxdsNARl13HIeUuipBx7S
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2023 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  8367cdaa31a8bb7fdcadab31deed48a5
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-dijkstra
hs-libraries:         HSmonad-dijkstra-0.1.1.5-HpxdsNARl13HIeUuipBx7S
depends:
    base-4.17.2.1 containers-0.6.7 free-5.2-8n63L5XNWv09r5UXg2kWUU
    mtl-2.2.2 psqueues-0.2.8.2-HljXvBZwZgI6MLPjgVBkJp
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-dijkstra-0.1.1.5-167-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-dijkstra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-dijkstra
version:              0.1.1.5
visibility:           public
id:                   monad-dijkstra-0.1.1.5-5rSBrcHqoNzKCbv1Viqsw2
key:                  monad-dijkstra-0.1.1.5-5rSBrcHqoNzKCbv1Viqsw2
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2023 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  5acd16db4804eb42b2214dc5ad2d4729
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-dijkstra-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-dijkstra
hs-libraries:         HSmonad-dijkstra-0.1.1.5-5rSBrcHqoNzKCbv1Viqsw2
depends:
    base-4.17.2.1 containers-0.6.7 free-5.2-FO2Q20euwXcCdGr9UaAYL8
    mtl-2.2.2 psqueues-0.2.8.2-EPn97RMztrUF0ZPYb3MWTl
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
